Crate openrr_planner[−][src]
Motion Planning Library for Robotics
Get the collision free trajectory of joint angles. ncollide3d is used to check the
collision between the robot and the environment.
Modules
| collision |
Structs
| CollisionChecker | Collision checker for a robot |
| JacobianIkSolver | Inverse Kinematics Solver using Jacobian matrix |
| JointPathPlanner | Collision Avoidance Path Planner |
| JointPathPlannerBuilder | Builder pattern to create |
| JointPathPlannerWithIK | Joint path planner which supports inverse kinematics |
| RandomInitializeIKSolver | Randomize initial joint angles before solving |
| TrajectoryPoint | Struct for a point of a trajectory with multiple dimensions. |
Enums
| Error | Error for |
Traits
| FromUrdf | Convert urdf object into openrr_planner/ncollide3d object |
| InverseKinematicsSolver | IK solver |
Functions
| generate_clamped_joint_positions_from_limits | Clamp joint angles to set angles safely |
| generate_random_joint_positions_from_limits | Generate random joint angles from the optional limits |
| get_reachable_region | Check the poses which can be reached by the robot arm |
| interpolate | Interpolate position vectors |
| modify_to_nearest_angle | If the joint has no limit, select the nearest value from (x + 2pi *). |
| set_clamped_joint_positions | Deprecated Set joint positions safely |
| set_random_joint_positions | Set random joint angles |